@@ -17,7 +17,7 @@ from typing import List
 
 from botocore.response import StreamingBody
 
-from .literals import Status
+from .literals import StatusType
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -63,7 +63,7 @@ ChangedBlockTypeDef = TypedDict(
 CompleteSnapshotResponseTypeDef = TypedDict(
     "CompleteSnapshotResponseTypeDef",
     {
-        "Status": Status,
+        "Status": StatusType,
     },
     total=False,
 )
@@ -118,7 +118,7 @@ StartSnapshotResponseTypeDef = TypedDict(
         "Description": str,
         "SnapshotId": str,
         "OwnerId": str,
-        "Status": Status,
+        "Status": StatusType,
         "StartTime": datetime,
         "VolumeSize": int,
         "BlockSize": int,
